Overview and usage is here
Modules
Structs
- Entry
Options - Entry options
- Error
- FsUri
- URI for a file or directory.
- Size
- Image size
- Storage
Volume - Storage volume metadata
- Storage
Volume Id
Enums
- AppDir
- Directory for the app’s use.
- Entry
- Entry
Type - Entry type
- File
Access Mode - Access mode.
- Image
Format - Optional
Entry - Persisted
UriPermission State - Persisted uri permission state
- Private
Dir - Directory for the app’s use only.
- Progress
Notification Icon - Icon type used for notification UI.
- Public
Audio Dir - Directory in which to place audios that are available to other applications and users.
- Public
Dir - Directory in which to place files that are available to other applications and users.
- Public
General Purpose Dir - Directory in which to place files that are available to other applications and users.
- Public
Image Dir - Directory in which to place images that are available to other applications and users.
- Public
Video Dir - Directory in which to place videos that are available to other applications and users.
- UriPermission
- Uri permission
- Visual
Media Target - Filters for VisualMediaPicker.
Traits
Functions
- init
- Initializes the plugin.