FileUri

Type Alias FileUri 

pub type FileUri = FsUri;
👎Deprecated:

Use tauri_plugin_android_fs::FsUri instead.

Aliased Type

pub struct FileUri {
    pub uri: String,
    pub document_top_tree_uri: Option<String>,
}

Fields

uri: String

URI for a file or directory.

Note

This is a URI with either the content or file scheme.

document_top_tree_uri: Option<String>

Document tree URI of the root directory from which this entry originates.

Note

This field is set for directories obtained via Directory Picker and for entries derived from those directories.