Crate tauri_plugin_android_fs

Crate tauri_plugin_android_fs 

Overview and usage is here

Modules

api
api_level
Constants representing Android API levels.

Structs

EntryOptions
Entry options
Error
FsUri
URI for a file or directory.
Size
Image size
StorageVolume
Storage volume metadata
StorageVolumeId

Enums

AppDir
Directory for the app’s use.
Entry
EntryType
Entry type
FileAccessMode
Access mode.
ImageFormat
OptionalEntry
PersistedUriPermissionState
Persisted uri permission state
PrivateDir
Directory for the app’s use only.
ProgressNotificationIcon
Icon type used for notification UI.
PublicAudioDir
Directory in which to place audios that are available to other applications and users.
PublicDir
Directory in which to place files that are available to other applications and users.
PublicGeneralPurposeDir
Directory in which to place files that are available to other applications and users.
PublicImageDir
Directory in which to place images that are available to other applications and users.
PublicVideoDir
Directory in which to place videos that are available to other applications and users.
UriPermission
Uri permission
VisualMediaTarget
Filters for VisualMediaPicker.

Traits

AndroidFsExt

Functions

init
Initializes the plugin.

Type Aliases

Result